summaryrefslogtreecommitdiffstats
path: root/lib/widgets/propeditor/pfontcombo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/widgets/propeditor/pfontcombo.cpp')
-rw-r--r--lib/widgets/propeditor/pfontcombo.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/widgets/propeditor/pfontcombo.cpp b/lib/widgets/propeditor/pfontcombo.cpp
index 8b0ee7a7..0675a6e0 100644
--- a/lib/widgets/propeditor/pfontcombo.cpp
+++ b/lib/widgets/propeditor/pfontcombo.cpp
@@ -37,11 +37,11 @@ PFontCombo::PFontCombo(MultiProperty *property, TQWidget *parent, const char *na
:PropertyWidget(property, parent, name)
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
- m_edit = new KFontCombo(this);
+ m_edit = new TDEFontCombo(this);
m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
/*adymo: KFontCombo seems to have a bug: when it is not editable, the signals
activated(int) and textChanged(const TQString &) are not emitted*/
#ifdef PURE_QT
TQFontDatabase fonts;
@@ -37,11 +37,11 @@ PFontCombo::PFontCombo(MultiProperty *property, TQWidget *parent, const char *na
m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
- /*adymo: KFontCombo seems to have a bug: when it is not editable, the signals
+ /*adymo: TDEFontCombo seems to have a bug: when it is not editable, the signals
activated(int) and textChanged(const TQString &) are not emitted*/
#ifdef PURE_QT